#I have used this simple script to find all cases, when a curve is a normal (parentType = 0) parent of a mesh object,
#and, simulateously, the mesh uses it in a CurveDeform modifier.
#You should never use the Curve object as parent. Such "pairs" display strange behavior in the first 100 frames of the animation.
#The solution is usually is simple: use the Curve in the CurveDeform modifier, and assign the mesh to Curve's parent.
#In a big model, like this, it is difficult to make sure, that all such "bad relationships" have been identified. 
#This scripts searches for them, and highlight the first case found. Highlighted objects are: the mesh and the curve's parent.
#The script makes their layers visible, so you can quickly locate them using View-->Align View-->Align View To Selected (NumPad *) 
#command.
#These selected obejcts are ready just for your "make parent" (Ctrl+P) command, if there are no any other obstacles.
import bpy 
import Blender
from Blender import *

def main():
	"""just the main procedure of this script
	"""
	if Object.GetSelected():
		Draw.PupMenu("Cannot select objects:%t|Run this script, when no object is selected")
	else:
		found = False
		for object in bpy.data.objects : 
			if object.type == 'Mesh' and object.parentType == 0 and object.parent and object.parent.type == 'Curve':
				Draw.PupMenu("Curve's child found:%t|Assign it to this new parent (just typing Ctrl-P)")
				new_parent = object.parent.parent
				object.select(1)
				new_parent.select(1)
				Scene.getCurrent().setLayers(object.layers + new_parent.layers) #switch into layers, where these objects are located
				print(object.name)
				print(new_parent.name)
				Window.RedrawAll() 
				found = True
				break
		if not found : Draw.PupMenu("No curve's child found:%t|Congratulations! This model is free of them.")
		
#let's run the whole thing:
main()